<?php

namespace App\Http\Controllers;

use App\Models\BlogPost;
use App\Models\PostLike;
use App\Models\About;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\File;
use App\Http\Requests\PostStoreRequest;
use App\Http\Resources\BlogPostResource;
use App\Http\Requests\PostCommentRequest;
use App\Models\Question;
use App\Providers\RouteServiceProvider;
use Illuminate\Http\Request;
use Inertia\Inertia;

class BlogPostController extends Controller
{
    public function index()
    {
        $user = Auth::user() ?? [];

        $question = Question::query()
            ->where('valid', 1)
            ->get()
            ->random();
        $allQuestions = Question::query()->where('valid', 1)
        ->get();
        $posts = BlogPost::query()
            ->with(['user', 'blogFile', 'question', 'comments'])
            ->latest()->get();

        $posts = BlogPostResource::collection($posts);
        $about = About::query()->first();
        $about->short_description = substr( $about->description, 0, 339);

        return Inertia::render('Index', compact('posts', 'question', 'user','about','allQuestions'));
    }

    public function getQuestion(){
        $question = Question::query()
        ->where('valid', 1)
        ->get()
        ->random();
        return response($question);
    }
    public function gallery()
    {
        // dd('hello');
        $user = Auth::user() ?? [];

        $question = Question::query()
            ->where('valid', 1)
            ->get()
            ->random();

        $posts = BlogPost::query()
            ->with(['user', 'blogFile', 'question', 'comments'])
            ->latest()->get();

        $posts = BlogPostResource::collection($posts);
        $about = About::query()->first();
        $about->short_description = substr( $about->description, 0, 339);

        return Inertia::render('Gallery', compact('posts', 'question', 'user','about'));
    }

    public function store(PostStoreRequest $request)
    {
        DB::beginTransaction();
        try {
            $postFiles = [];
            $data = $request->validated();
            $data['date'] = now();
            $data['valid'] = 0;

            $post = BlogPost::create($data);

            if (isset($data['image'])) {
                $relativePath = $this->saveImage($data['image']);

                $postFiles['post_image'] = $relativePath;
                $postFiles['date'] = now();
                $postFiles['created_by'] = $data['created_by'];
                $postFiles['status'] = 1;
                $postFiles['valid'] = 0;

                $post->blogFile()->create($postFiles);
            }

            DB::commit();

            $post = new BlogPostResource($post);

            return redirect()->route('home');
        } catch (\Exception $e) {
            DB::rollback();
            throw $e->getMessage();
        }
    }

    public function storeQuestion(Request $request){
        // dd($request);
        // $data = $request;
        // $data['status'] = 1;
        Question::create([
            'relationship_id' => $request->relationship_id,
            'name' => $request->name,
            'status' => 1,
            'created_by' => $request->created_by,
            'updated_by' => $request->updated_by,
        ]);
        return redirect()->route('home');
    }

    public function comment(PostCommentRequest $request)
    {
        $data = $request->validated();
        $data['date'] = now();
        $data['status'] = 1;

        $post = BlogPost::findOrFail($data['post_id']);

        if (isset($data['image'])) {
            $relativePath = $this->saveImage($data['image']);
            $data['post_image'] = $relativePath;
        }

        $post->comments()->create($data);

        return redirect()->route('home');
    }

    public function like(BlogPost $post, Request $request)
    {
        $post->likes()->create([
            'user_id' => $request->input('user_id'),
            'blog_post_id' => $post->id
        ]);

        return redirect()->route('home');
    }

    public function unlike(BlogPost $post, Request $request)
    {
        $like = PostLike::query()
            ->where('user_id', $request->input('user_id'))
            ->where('blog_post_id', $post->id)
            ->delete();
        return redirect()->route('home');
    }

    /**
     * Save image in file
     *
     * @param [type] $image
     * @return string
     */
    private function saveImage($image)
    {
        if (preg_match('/^data:image\/(\w+);base64,/', $image, $type)) {
            $image = substr($image, strpos($image, ',') + 1);
            $type = strtolower($type[1]);

            if (!in_array($type, ['jpg', 'jpeg', 'gif', 'png'])) {
                throw new \Exception('Invalid image type');
            }

            $image = str_replace(' ', '+', $image);
            $image = base64_decode($image);

            if ($image === false) {
                throw new \Exception('base64_decode faild');
            }
        } else {
            throw new \Exception('did not match data URL with image data');
        }

        $dir = 'images/';
        $file = Str::random() . '.' . $type;
        $absolutePath = public_path($dir);
        $relativePath = $dir . $file;

        if (!File::exists($absolutePath)) {
            File::makeDirectory($absolutePath, 0755, true);
        }
        file_put_contents($relativePath, $image);

        return $relativePath;
    }
}
