<?php
use App\Http\Controllers\Admin\AdminProfileController;
use App\Http\Controllers\BlogPostController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\GuestController;
use Illuminate\Foundation\Application;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Auth\ProviderController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/auth/{google}/redirect', [ProviderController::class, 'redirect']);
Route::get('/auth/{google}/callback', [ProviderController::class, 'callback'])->name('auth.callback');

Route::get('/', [BlogPostController::class, 'index'])->name('home');
Route::get('/gallery', [BlogPostController::class, 'gallery'])->name('gallery');
Route::get('/getQuestion', [BlogPostController::class, 'getQuestion'])->name('getQuestion');
Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');

    Route::post('posts/{post}/like', [BlogPostController::class, 'like'])->name('posts.like');
    Route::delete('posts/{post}/unlike', [BlogPostController::class, 'unlike'])->name('posts.unlike');
    Route::post('posts/comment', [BlogPostController::class, 'comment'])->name('posts.comment');
    Route::post('posts', [BlogPostController::class, 'store'])->name('post.store');
    Route::post('question', [BlogPostController::class, 'storeQuestion'])->name('question.storeQuestion');
});


Route::get('memory', function () {
    return Inertia::render('Memory');
})->name('memory');

// Route::get('gallery', function () {
//     return Inertia::render('Gallery');
// })->name('gallery');

// Route::get('guestbook', function () {
//     return Inertia::render('Guestbook');
// })->name('guestbook');

Route::get('/guestbook', [GuestController::class, 'index'])->name('guestbook');



Route::get('/dashboard', function () {
    return Inertia::render('Dashboard');
})->middleware(['auth', 'verified'])->name('dashboard');

require __DIR__ . '/auth.php';
require __DIR__ . '/AdminAuth.php';

Route::middleware('auth:admin')->group(function () {
    Route::get('/admin/dashboard', function () {
        return Inertia::render('Admin/Dashboard');
    })->name('admin.dashboard');
    Route::get('/admin/profile', [AdminProfileController::class, 'edit'])->name('admin.profile.edit');
});